@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 from refinery.lib.meta import metavars, LazyMetaOracle
 from refinery.lib.frame import Chunk
 
@@ -15,21 +15,21 @@ class cm(Unit):
     """
     def __init__(
         self,
-        invert  : arg.switch('-x', group='ALL', help='populate only options that have not been specified') = False,
-        all     : arg.switch('-a', group='ALL', help='populate all options') = False,
-        reset   : arg.switch('-r', help='discard all meta variables that were not explicitly specified') = False,
-        size    : arg.switch('-S', help='size of the chunk') = False,
-        index   : arg.switch('-I', help='index of the chunk in the current frame') = False,
-        ext     : arg.switch('-F', help='guess file extension') = False,
-        entropy : arg.switch('-E', help='compute data entropy') = False,
-        ic      : arg.switch('-C', help='compute the index of coincidence') = False,
-        magic   : arg.switch('-M', help='compute file magic') = False,
-        sha1    : arg.switch('-1', help='compute hash: SHA-1') = False,
-        sha256  : arg.switch('-2', help='compute hash: SHA-256') = False,
-        crc32   : arg.switch('-3', help='compute hash: CRC32') = False,
-        md5     : arg.switch('-5', help='compute hash: MD5') = False,
-        hashes  : arg.switch('-H', help='compute all common hashes') = False,
-        *names  : arg(metavar='name', help=(
+        invert  : Arg.Switch('-x', group='ALL', help='populate only options that have not been specified') = False,
+        all     : Arg.Switch('-a', group='ALL', help='populate all options') = False,
+        reset   : Arg.Switch('-r', help='discard all meta variables that were not explicitly specified') = False,
+        size    : Arg.Switch('-S', help='size of the chunk') = False,
+        index   : Arg.Switch('-I', help='index of the chunk in the current frame') = False,
+        ext     : Arg.Switch('-F', help='guess file extension') = False,
+        entropy : Arg.Switch('-E', help='compute data entropy') = False,
+        ic      : Arg.Switch('-C', help='compute the index of coincidence') = False,
+        magic   : Arg.Switch('-M', help='compute file magic') = False,
+        sha1    : Arg.Switch('-1', help='compute hash: SHA-1') = False,
+        sha256  : Arg.Switch('-2', help='compute hash: SHA-256') = False,
+        crc32   : Arg.Switch('-3', help='compute hash: CRC32') = False,
+        md5     : Arg.Switch('-5', help='compute hash: MD5') = False,
+        hashes  : Arg.Switch('-H', help='compute all common hashes') = False,
+        *names  : Arg(metavar='name', help=(
             F'A variable name that can include the common properties: {_COMMON_PROPERTIES_LIST}.'
             R' If none is given, the variables index and size are populated. For most of these,'
             R' an optional argument is available that can be used as a shorthand:'))
