@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit, Chunk
 
 
 class push(Unit):
@@ -16,11 +16,11 @@ class push(Unit):
     data into just the value, which is then stored in the variable `v`. The application
     of `refinery.repl` replaces this value with the hard-coded string `censored`.
     """
-    def __init__(self, data: arg(help='The data to be pushed, by default a copy of the input.') = B''):
+    def __init__(self, data: Arg(help='The data to be pushed, by default a copy of the input.') = B''):
         super().__init__(data=data)
 
-    def process(self, data):
-        yield self.args.data or data
+    def process(self, data: Chunk):
+        tos = self.args.data or data.copy()
         if self.args.nesting > 0:
             data.set_next_scope(False)
         else:
@@ -29,3 +29,4 @@ class push(Unit):
             except AttributeError:
                 self.log_warn('application has no effect outside frame.')
         yield data
+        yield tos
