@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 from refinery.lib.tools import terminalfit
 from refinery.lib.decorators import unicoded
 
@@ -12,8 +12,8 @@ class termfit(Unit):
 
     def __init__(
         self,
-        width: arg('width', help='Optionally specify the width, by default the current terminal width is used.') = 0,
-        delta: arg.number('-d', help='Subtract this number from the calculated width (0 by default).') = 0,
+        width: Arg('width', help='Optionally specify the width, by default the current terminal width is used.') = 0,
+        delta: Arg.Number('-d', help='Subtract this number from the calculated width (0 by default).') = 0,
     ):
         super().__init__(width=width, delta=delta)
 
